Index: trunk/MagicSoft/Mars/mtemp/mifae/Changelog
===================================================================
--- trunk/MagicSoft/Mars/mtemp/mifae/Changelog	(revision 4201)
+++ trunk/MagicSoft/Mars/mtemp/mifae/Changelog	(revision 4202)
@@ -19,4 +19,10 @@
                                                  -*-*- END OF LINE -*-*-
 
+	
+ 2004/05/24 Javier Rico
+   * library/MHillasDisplay.[h,cc]
+     - Call for MIslands::Print() in the process if any MIslands is 
+       found
+	
  2004/05/24 Javier Rico
    * library/MDisplay.[h,cc], programs/makeHillas.cc, 
Index: trunk/MagicSoft/Mars/mtemp/mifae/library/MHillasDisplay.cc
===================================================================
--- trunk/MagicSoft/Mars/mtemp/mifae/library/MHillasDisplay.cc	(revision 4201)
+++ trunk/MagicSoft/Mars/mtemp/mifae/library/MHillasDisplay.cc	(revision 4202)
@@ -36,4 +36,5 @@
 //  MHillas
 //  [MSrcPosCam]
+//  [MIslands]
 //
 // Output containers
@@ -58,5 +59,5 @@
 #include "MNewImagePar.h"
 #include "MSrcPosCam.h"
-
+#include "MIslands.h"
 
 ClassImp(MHillasDisplay);
@@ -104,5 +105,5 @@
     *fLog << warn << "MHillasDisplay::PreProcess Warning: MNewImagePar object not found" << endl;
 
-  // Look for the MHillas container  
+  // Look for the MSrcPosCam container  
   if(!fSrcPos)
     fSrcPos = (MSrcPosCam*)pList->FindObject(AddSerialNumber("MSrcPosCam"), "MSrcPosCam");
@@ -110,4 +111,10 @@
     *fLog << warn << "MHillasDisplay::PreProcess Warning: MSrcPosCam object not found" << endl;
 
+  // Look for the MIslands container  
+  if(!fIslands)
+    fIslands = (MIslands*)pList->FindObject(AddSerialNumber("MIslands"), "MIslands");
+  if(!fIslands)
+    *fLog << warn << "MHillasDisplay::PreProcess Warning: MIslands object not found" << endl;
+
   return kTRUE;
 }
@@ -119,9 +126,13 @@
 {
    // draw the hillas parameters
-  if(fHillas && GetPauseMode())
-    fHillas->Print();
-  if(fNewImage && GetPauseMode())
-    fNewImage->Print();
-      
+  if(GetPauseMode())
+    {
+      if(fHillas)
+	fHillas->Print();
+      if(fNewImage)
+	fNewImage->Print();
+      if(fIslands)
+	fIslands->Print();
+    }      
    
   // draw the event
Index: trunk/MagicSoft/Mars/mtemp/mifae/library/MHillasDisplay.h
===================================================================
--- trunk/MagicSoft/Mars/mtemp/mifae/library/MHillasDisplay.h	(revision 4201)
+++ trunk/MagicSoft/Mars/mtemp/mifae/library/MHillasDisplay.h	(revision 4202)
@@ -10,4 +10,5 @@
 class MGeomCam;
 class MHillas;
+class MIslands;
 class MNewImagePar;
 
@@ -17,5 +18,6 @@
   MHillas*      fHillas;    // pointer to container with the hillas parameters
   MNewImagePar* fNewImage;  // pointer to container with the new image parameters
-  MSrcPosCam*   fSrcPos;     // pointer to the source position in camera
+  MSrcPosCam*   fSrcPos;    // pointer to the source position in camera
+  MIslands*     fIslands;   // pointer to the islands
 
   virtual Int_t PreProcess(MParList *plist);
@@ -28,6 +30,7 @@
   virtual ~MHillasDisplay(){};
 
-  void SetHillas(MHillas* hillas) {fHillas=hillas;}
+  void SetHillas(MHillas* hillas)    {fHillas=hillas;}
   void SetSrcPos(MSrcPosCam* srcpos) {fSrcPos=srcpos;}
+  void SetIslands(MIslands* islands) {fIslands=islands;}
 
   virtual void Paint(Option_t* option);
